import Vue from 'vue'
import Router from 'vue-router'


Vue.use(Router)
/**
 * Note: 路由配置项
 * name:'router-name'             // 设定路由的名字，一定要填写不然使用<keep-alive>时会出现各种问题
 * meta : {
    keepAlive: true              // 如果设置为true，则会被 <keep-alive> 缓存 (默认 false)
    title: 'title'               // 设置该路由在页面顶部的Title
    index: '1'                   // 设置该路由页面切换是否左右滑动及权重，如不设页面不滑动  PS：功能暂时未启用
    hidden: true                 // 如果设置为true，显示底部菜单，如不设或者false，不显示
  }
 */
export const constantRoutes = [
  {
    path: '/',
    redirect: '/index'
  },
  {
    path: '/index',
    name: 'index',
    meta: {
      title: '主页',
      keepAlive: true
    },
    component: (resolve) => require(['@/views/index'], resolve)
  },
  {
    path: '/login',
    name: 'login',
    meta: {
      title: '登录页',
      hidden: true,
    },
    component: (resolve) => require(['@/views/login'], resolve)
  },
  {
    path: '/register',
    name: 'register',
    meta: {
      title: '注册页',
      hidden: true,
    },
    component: (resolve) => require(['@/views/register'], resolve)
  },
  {
    path: '/document',
    name: 'document',
    meta: {
      title: '文档',
    },
    component: (resolve) => require(['@/views/document'], resolve)
  },
  {
    path: '/workbench',
    name: 'workbench',
    meta: {
      title: '工作台'
    },
    component: (resolve) => require(['@/views/workbench'], resolve)
  },
  {
    path: '/addressBook',
    name: 'addressBook',
    meta: {
      title: '通讯录'
    },
    component: (resolve) => require(['@/views/addressBook'], resolve)
  },
  {
    path: '/mynsgk',
    name: 'mynsgk',
    meta: {
      title: '我的'
    },
    component: (resolve) => require(['@/views/mynsgk'], resolve)
  } ,
  {
    path: '/authenticRight',
    name: 'authenticRight',
    meta: {
      title: '确权颁证调查统计表',
    },
    component: (resolve) => require(['@/views/authenticRight/index'], resolve)
  },
  {
    path: '/biddingHall',
    name: 'biddingHall',
    meta: {
      title: '竞价大厅',
      hidden: true,
    },
    component: (resolve) => require(['@/views/biddingHall'], resolve)
  },
  {
    path: '/project',
    name: 'project',
    meta: {
      title: '挂牌项目'
    },
    component: (resolve) => require(['@/views/project'], resolve)
  },
  {
    path: '/project/projectDetail',
    name: 'projectDetail',
    meta: {
      title: '挂牌项目',
      hidden: true
    },
    component: (resolve) => require(['@/views/project/projectDetail'], resolve)
  },
  {
    path: '/news/index',
    name: 'news',
    meta: {
      title: '新闻资讯',
      hidden: true,
    },
    component: (resolve) => require(['@/views/news/index'], resolve)
  },
  {
    path: '/news/newDetail',
    name: 'newDetail',
    meta: {
      title: '新闻详情',
      hidden: true,
    },
    component: (resolve) => require(['@/views/news/newDetail'], resolve)
  },
  {
    path: '/notice/index',
    name: 'notice',
    meta: {
      title: '项目公告',
      hidden: true,
    },
    component: (resolve) => require(['@/views/notice/index'], resolve)
  },
  {
    path: '/supply/index',
    name: 'supply',
    meta: {
      title: '个人供求',
      hidden: true,
    },
    component: (resolve) => require(['@/views/supply/index'], resolve)
  },
  {
    path: '/interaction/index',
    name: 'interaction',
    meta: {
      title: '互动交流',
      hidden: true,
    },
    component: (resolve) => require(['@/views/interaction/index'], resolve)
  },
  {
    path: '/register/index',
    name: 'registerAgreement',
    meta: {
      title: '注册须知',
      hidden: true,
    },
    component: (resolve) => require(['@/views/register/index'], resolve)
  },
  {
    path: '/register/registerType',
    name: 'registerType',
    meta: {
      title: '注册类型',
      hidden: true,
    },
    component: (resolve) => require(['@/views/register/registerType'], resolve)
  },
  {
    path: '/register/userRegister',
    name: 'userRegister',
    meta: {
      title: '个人用户注册',
      hidden: true,
    },
    component: (resolve) => require(['@/views/register/userRegister'], resolve)
  },
  {
    path: '/register/companyRegister',
    name: 'companyRegister',
    meta: {
      title: '单位用户注册',
      hidden: true,
    },
    component: (resolve) => require(['@/views/register/companyRegister'], resolve)
  },
  {
    path: '/user',
    name: 'user',
    meta: {
      title: '个人中心',
    },
    component: (resolve) => require(['@/views/user/index'], resolve)
  },
  {
    path: '/accountSetting',
    name: 'accountSetting',
    meta: {
      title: '账户设置',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/accountSetting/index'], resolve)
  },
  {
    path: '/companyInformation',
    name: 'companyInformation',
    meta: {
      title: '资料修改',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/accountSetting/userInformation/companyInformation'], resolve)
  },
  {
    path: '/userInformation',
    name: 'userInformation',
    meta: {
      title: '资料修改',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/accountSetting/userInformation/userInformation'], resolve)
  },
  {
    path: '/bankInformation',
    name: 'bankInformation',
    meta: {
      title: '银行账户修改',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/accountSetting/bankInformation/index'], resolve)
  },
  {
    path: '/passWordInformation',
    name: 'passWordInformation',
    meta: {
      title: '密码修改',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/accountSetting/passWordInformation/index'], resolve)
  },
  {
    path: '/phoneInformation',
    name: 'phoneInformation',
    meta: {
      title: '手机号修改',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/accountSetting/phoneInformation/index'], resolve)
  },
  {
    path: '/bidding',
    name: 'bidding',
    meta: {
      title: '我的竞价',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/bidding/index'], resolve)
  },
  {
    path: '/userInteraction',
    name: 'userInteraction',
    meta: {
      title: '我的咨询',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/interaction/index'], resolve)
  },
  {
    path: '/userSupply',
    name: 'userSupply',
    meta: {
      title: '我的供求',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/supply/index'], resolve)
  },
  {
    path: '/policy',
    name: 'policy',
    meta: {
      title: '政策法规',
      hidden: true,
    },
    component: (resolve) => require(['@/views/policy/index'], resolve)
  },
  {
    path: '/project/signUp',
    name: 'signUp',
    meta: {
      title: '报名',
      hidden: true
    },
    component: (resolve) => require(['@/views/project/signUp'], resolve)
  },
  {
    path: '/noticeDetail',
    name: 'noticeDetail',
    meta: {
      title: '公告详情',
      hidden: true,
    },
    component: (resolve) => require(['@/views/notice/noticeDetail'], resolve)
  },
  {
    path: '/attestationDetail',
    name: 'attestationDetail',
    meta: {
      title: '鉴证详情',
      hidden: true,
    },
    component: (resolve) => require(['@/views/notice/attestationDetail'], resolve)
  },
  {
    path: '/policyDetail',
    name: 'policyDetail',
    meta: {
      title: '政策法规',
      hidden: true,
    },
    component: (resolve) => require(['@/views/policy/policyDetail'], resolve)
  },
  {
    path: '/interactionAdd',
    name: 'interactionAdd',
    meta: {
      title: '添加互动交流',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/interaction/interactionAdd'], resolve)
  },
  {
    path: '/supplyAdd',
    name: 'supplyAdd',
    meta: {
      title: '添加互动交流',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/supply/supplyAdd'], resolve)
  },
  //两清三化宅基地
  {
    path: '/homestead/index',
    name: 'homesteadIndex',
    meta: {
      title: '两清三化宅基地',
      hidden: true,
    },
    component: (resolve) => require(['@/views/homestead/index'], resolve)
  },
  {
    path: '/homestead/login',
    name: 'homesteadLogin',
    meta: {
      title: '登录页',
      hidden: true,
    },
    component: (resolve) => require(['@/views/homestead/login'], resolve)
  },
//两清三化宅基地
  {
    path: '/authenticRight/index',
    name: 'authenticRightIndex',
    meta: {
      title: '两清三化宅基地',
      hidden: true,
    },
    component: (resolve) => require(['@/views/authenticRight/index'], resolve)
  },
  {
    path: '/authenticRight/login',
    name: 'authenticRightLogin',
    meta: {
      title: '登录页',
      hidden: true,
    },
    component: (resolve) => require(['@/views/authenticRight/login'], resolve)
  },
  {
    path: '/onlineHomeLogin',
    name: 'onlineHomeLogin',
    meta: {
      title: '登录页',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHomeLogin'], resolve)
  },
  {
    path: '/onlineHomeIndex',
    name: 'onlineHomeIndex',
    meta: {
      title: '网上家园',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHomeIndex'], resolve)
  },
  {
    path: '/onlineHome/publicity',
    name: 'onlineHomePublicity',
    meta: {
      title: '公示',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/publicity'], resolve)
  },
  {
    path: '/onlineHome/workbench',
    name: 'onlineHomeWorkbench',
    meta: {
      title: '公示',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/workbench'], resolve)
  },
  {
    path: '/onlineHome/home',
    name: 'onlineHomeHome',
    meta: {
      title: '公示',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/home'], resolve)
  },
  {
    path: '/onlineHome/my',
    name: 'onlineHomeMy',
    meta: {
      title: '公示',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/my'], resolve)
  },
  {
    path: '/onlineHome/threeAffairs',
    name: 'onlineHomeThreeAffairs',
    meta: {
      title: '三务公开',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/threeAffairs'], resolve)
  },
  {
    path: '/onlineHome/homePoll',
    name: 'onlineHomeHomePoll',
    meta: {
      title: '投票',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homePoll'], resolve)
  },
  {
    path: '/onlineHome/incomeDetail',
    name: 'onlineHomeIncomeDetail',
    meta: {
      title: '收入明细公开表',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/incomeDetail'], resolve)
  },
  {
    path: '/onlineHome/expenditureDetail',
    name: 'onlineHomeExpenditureDetail',
    meta: {
      title: '支出明细公开表',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/expenditureDetail'], resolve)
  },
  {
    path: '/onlineHome/inAndOutDetail',
    name: 'onlineHomeInAndOutDetail',
    meta: {
      title: '收支明细公开表',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/inAndOutDetail'], resolve)
  },
  {
    path: '/onlineHome/mailList',
    name: 'onlineHomeMailList',
    meta: {
      title: '通讯录',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/mailList'], resolve)
  }
  ,
  {
    path: '/onlineHome/password',
    name: 'onlineHomePassword',
    meta: {
      title: '密码修改',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/password'], resolve)
  },
  {
    path: '/onlineHome/livePay',
    name: 'onlineHomeLivePay',
    meta: {
      title: '生活缴费',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/livePay'], resolve)
  },
  {
    path: '/onlineHome/personalPicture',
    name: 'onlineHomePersonalPicture',
    meta: {
      title: '画像',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/personalPicture'], resolve)
  },
  {
    path: '/onlineHome/done',
    name: 'onlineHomeDone',
    meta: {
      title: '我的已办',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/done'], resolve)
  },
  {
    path: '/onlineHome/advice',
    name: 'onlineHomeAdvice',
    meta: {
      title: '投诉建议',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/advice'], resolve)
  },
  {
    path: '/applicationForm',
    name: 'applicationForm',
    meta: {
      title: '农村宅基地申请表',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/homeApplication/applicationForm'], resolve)
  },
  {
    path: '/applicationList',
    name: 'applicationList',
    meta: {
      title: '宅基地申请',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/homeApplication/applicationList'], resolve)
  },
  {
    path: '/certificateList',
    name: 'certificateList',
    meta: {
      title: '证书查看',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/certificate/certificateList'], resolve)
  },
  {
    path: '/certificateSee',
    name: 'certificateSee',
    meta: {
      title: '证书查看',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/certificate/certificateSee'], resolve)
  },
  {
    path: '/informationList',
    name: 'informationList',
    meta: {
      title: '公示信息',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/publicityInformation/informationList'], resolve)
  },
  {
    path: '/informationDetail',
    name: 'informationDetail',
    meta: {
      title: '公示信息',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/publicityInformation/informationDetail'], resolve)
  },
  {
    path: '/circulationList',
    name: 'circulationList',
    meta: {
      title: '使用权流转',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/circulation/circulationList'], resolve)
  },
  {
    path: '/circulationAdd',
    name: 'circulationAdd',
    meta: {
      title: '添加宅基地使用流转权',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/circulation/circulationAdd'], resolve)
  }
  ,
  {
    path: '/onlineHome/zcfg',
    name: 'zcfg',
    meta: {
      title: '政策法规',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/zcfg'], resolve)
  },
  {
    path: '/onlineHome/hnzc',
    name: 'hnzc',
    meta: {
      title: '惠农政策',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/hnzc'], resolve)
  },
  {
    path: '/onlineHome/gzdt',
    name: 'gzdt',
    meta: {
      title: '工作动态',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/gzdt'], resolve)
  },
  {
    path: '/onlineHome/zdjs',
    name: 'zdjs',
    meta: {
      title: '制度建设',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/zdjs'], resolve)
  },
  {
    path: '/onlineHome/homePollDetail',
    name: 'homePollDetail',
    meta: {
      title: '投票详情',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homePollDetail'], resolve)
  },
  {
    path: '/flowChart',
    name: 'flowChart',
    meta: {
      title: '宅基地申请流程',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/flowChart/index'], resolve)
  },
  {
    path: '/applicationAdd',
    name: 'applicationAdd',
    meta: {
      title: '宅基地申请流程',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/homeApplication/applicationAdd'], resolve)
  },
  {
    path: '/paidExit',
    name: 'paidExit',
    meta: {
      title: '有偿退出',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/paidExit/paidExitList'], resolve)
  },
  {
    path: '/paidExitAdd',
    name: 'paidExitAdd',
    meta: {
      title: '有偿退出',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/paidExit/paidExitAdd'], resolve)
  },
  {
    path: '/mortgage',
    name: 'mortgage',
    meta: {
      title: '使用权抵押',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/mortgage/mortgageList'], resolve)
  },
  {
    path: '/mortgageAdd',
    name: 'mortgageAdd',
    meta: {
      title: '使用权抵押',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/mortgage/mortgageAdd'], resolve)
  },
  {
    path: '/utilization',
    name: 'utilization',
    meta: {
      title: '农房利用',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/utilization/utilizationList'], resolve)
  },
  {
    path: '/utilizationDetail',
    name: 'utilizationDetail',
    meta: {
      title: '农房利用',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/utilization/utilizationDetail'], resolve)
  },
  {
    path: '/utilizationAdd',
    name: 'utilizationAdd',
    meta: {
      title: '农房利用',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/utilization/utilizationAdd'], resolve)
  },
  {
    path: '/utilizationModify',
    name: 'utilizationModify',
    meta: {
      title: '农房利用',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/utilization/utilizationModify'], resolve)
  },
  {
    path: '/homesteadUtilize',
    name: 'homesteadUtilize',
    meta: {
      title: '宅基地利用情况',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/homesteadUtilize/homesteadUtilize'], resolve)
  },
  {
    path: '/homesteadUtilizeAdd',
    name: 'homesteadUtilizeAdd',
    meta: {
      title: '宅基地利用情况',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/homesteadUtilize/homesteadUtilizeAdd'], resolve)
  },
  {
    path: '/homesteadUtilizeDetail',
    name: 'homesteadUtilizeDetail',
    meta: {
      title: '宅基地利用情况',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/homesteadUtilize/homesteadUtilizeDetail'], resolve)
  },
  {
    path: '/homesteadUtilizeModify',
    name: 'homesteadUtilizeModify',
    meta: {
      title: '宅基地利用情况',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/homesteadUtilize/homesteadUtilizeModify'], resolve)
  },
  {
    path: '/circulationDetail',
    name: 'circulationDetail',
    meta: {
      title: '查看宅基地使用流转权',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/circulation/circulationDetail'], resolve)
  },
  {
    path: '/circulationModify',
    name: 'circulationModify',
    meta: {
      title: '修改宅基地使用流转权',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/circulation/circulationModify'], resolve)
  },
  {
    path: '/mortgageDetail',
    name: 'mortgageDetail',
    meta: {
      title: '查看使用权抵押',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/mortgage/mortgageDetail'], resolve)
  },
  {
    path: '/mortgageModify',
    name: 'mortgageModify',
    meta: {
      title: '修改使用权抵押',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/mortgage/mortgageModify'], resolve)
  },
  {
    path: '/paidExitDetail',
    name: 'paidExitDetail',
    meta: {
      title: '有偿退出详情',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/paidExit/paidExitDetail'], resolve)
  },
  {
    path: '/paidExitModify',
    name: 'paidExitModify',
    meta: {
      title: '有偿退出修改',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/paidExit/paidExitModify'], resolve)
  },
  {
    path: '/task',
    name: 'task',
    meta: {
      title: '发布任务',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/task/taskList'], resolve)
  },
  {
    path: '/taskRelease',
    name: 'taskRelease',
    meta: {
      title: '发布任务',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/task/taskRelease'], resolve)
  },
  {
    path: '/taskLssueAdd',
    name: 'taskLssueAdd',
    meta: {
      title: '添加任务下发',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/task/taskLssueAdd'], resolve)
  },
  {
    path: '/taskLssueModify',
    name: 'taskLssueModify',
    meta: {
      title: '修改任务下发',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/task/taskLssueModify'], resolve)
  },
  {
    path: '/taskCloseCaseAdd',
    name: 'taskCloseCaseAdd',
    meta: {
      title: '结案',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/reporting/taskCloseCaseAdd'], resolve)
  },
  {
    path: '/taskCloseCaseList',
    name: 'taskCloseCaseList',
    meta: {
      title: '上报明细',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/task/taskCloseCaseList'], resolve)
  },
  {
    path: '/taskReportingList',
    name: 'taskReportingList',
    meta: {
      title: '任务上报',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/reporting/taskReportingList'], resolve)
  },
  {
    path: '/taskReportingDetail',
    name: 'taskReportingDetail',
    meta: {
      title: '结案',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/reporting/taskReportingDetail'], resolve)
  },
  {
    path: '/taskDetailedList',
    name: 'taskDetailedList',
    meta: {
      title: '上报明细',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/reporting/taskDetailedList'], resolve)
  },
  {
    path: '/taskReportingAdd',
    name: 'taskReportingAdd',
    meta: {
      title: '任务上报',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/reporting/taskReportingAdd'], resolve)
  },
  {
    path: '/supervisionList',
    name: 'supervisionList',
    meta: {
      title: '违法监管',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/supervision/supervisionList'], resolve)
  },
  {
    path: '/supervisionAdd',
    name: 'supervisionAdd',
    meta: {
      title: '添加宅基地监管',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/supervision/supervisionAdd'], resolve)
  },
  {
    path: '/supervisionModify',
    name: 'supervisionModify',
    meta: {
      title: '修改宅基地监管',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/supervision/supervisionModify'], resolve)
  },
  {
    path: '/supervisionCloseCase',
    name: 'supervisionCloseCase',
    meta: {
      title: '修改宅基地监管',
      hidden: true,
    },
    component: (resolve) => require(['@/views/onlineHome/homestead/supervision/supervisionCloseCase'], resolve)
  }
];


export default new Router({
  linkActiveClass: 'active',
  mode: 'history', // 去掉url中的#
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})
